==> sadad_payment_flutter-0.0.35.tar.gz: lib/assets/locale/english.dart <==
Map<String, String> en = {
  "Or Pay Using": "Or Pay Using",
  "Credit Card": "Credit Card",
  "Debit Card": "Debit Card",
  "Sadad Pay": "Sadad Pay",
  "Okay": "Okay",
  "Pay": "Pay",
  "Please try with valid amount!": "Please try with valid amount!",
  "The Given Transaction Amount is less than ": "The Given Transaction Amount is less than ",
  "Something went wrong. Please try again": "Something went wrong. Please try again",
  "Please enter amount upto 2 decimal points": "Please enter amount upto 2 decimal points",
  "American Express card not allowed for your merchant.": "American Express card not allowed for your merchant.",
  "(You are safe)": "(You are safe)",
  "Payment is Secured with 256bit SSL encryption ": "Payment is Secured with 256bit SSL encryption ",
  "When you choose to complete your payment using a debit card issued in Qatar, you will be temporarily redirected to the QPay website. Once the transaction is completed, you'll be taken back to the Sadad to view your confirmation.":
      "When you choose to complete your payment using a debit card issued in Qatar, you will be temporarily redirected to the QPay website. Once the transaction is completed, you'll be taken back to the Sadad to view your confirmation.",
  "Password": "Password",
  "Cell Number": "Cell Number",
  "Expiry / Validity": "Expiry / Validity",
  "Card Number": "Card Number",
  "Card Holder Name": "Card Holder Name",
  "Select an option to Pay ": "Select an option to Pay ",
  "Merchant has no permission to use SDK. Please contact to administrator.": "Merchant has no permission to use SDK. Please contact to administrator.",


  "100% secured Payment ": "100% secured Payment ",
  "Powered by Sadad": "Powered by Sadad",
  "Login with your Sadad account": "Login with your Sadad account",
  "CVV is the three digit number on the back of your credit/debit card.": "CVV is the three digit number on the back of your credit/debit card.",
  "What is CVV": "What is CVV",
  "Please enter card holder name": "Please enter card holder name",
  "Card holder name is invalid.": "Card holder name is invalid.",
  "Please enter card number": "Please enter card number",
  "Please enter a valid credit card number.": "Please enter a valid credit card number.",
  "We are not accepting this card": "We are not accepting this card",
  "This is not a valid credit card number": "This is not a valid credit card number",
  "Please enter expiry.": "Please enter expiry.",
  "Enter valid expiry.": "Enter valid expiry.",
  "Please enter CVV": "Please enter CVV",
  "Please enter valid expiry.": "Please enter valid expiry.",
  "Please enter valid CVV": "Please enter valid CVV",
  "Not Allowed": "Not Allowed",
  "Transaction is not allowed from your country.": "Transaction is not allowed from your country.",
  "Please enter cell number.": "Please enter cell number.",
  "Please enter valid cell number": "Please enter valid cell number",
  "Please enter password": "Please enter password",
  "Issue": "Issue",
  "We are not able to proceed please try again.": "We are not able to proceed please try again.",
  "Something went wrong": "Something went wrong",
  "OTP Verification": "OTP Verification",
  "OTP is valid Upto ": "OTP is valid Upto ",
  "Can't receive the OTP? ": "Can't receive the OTP? ",
  "Resend": "Resend",
  "seconds": "seconds",
};

==> sadad_payment_flutter-0.0.37.tar.gz: lib/assets/locale/english.dart <==
Map<String, String> en = {
  "Or Pay Using": "Or Pay Using",
  "Credit Card": "Credit Card",
  "Debit Card": "Debit Card",
  "Sadad Pay": "Sadad Pay",
  "Okay": "Okay",
  "Pay": "Pay",
  "Please try with valid amount!": "Please try with valid amount!",
  "The Given Transaction Amount is less than ": "The Given Transaction Amount is less than ",
  "Something went wrong. Please try again": "Something went wrong. Please try again",
  "Please enter amount upto 2 decimal points": "Please enter amount upto 2 decimal points",
  "American Express card not allowed for your merchant.": "American Express card not allowed for your merchant.",
  "(You are safe)": "(You are safe)",
  "Payment is Secured with 256bit SSL encryption ": "Payment is Secured with 256bit SSL encryption ",
  "When you choose to complete your payment using a debit card issued in Qatar, you will be temporarily redirected to the QPay website. Once the transaction is completed, you'll be taken back to the Sadad to view your confirmation.":
      "When you choose to complete your payment using a debit card issued in Qatar, you will be temporarily redirected to the QPay website. Once the transaction is completed, you'll be taken back to the Sadad to view your confirmation.",
  "Password": "Password",
  "Cell Number": "Cell Number",
  "Expiry / Validity": "Expiry / Validity",
  "Card Number": "Card Number",
  "Card Holder Name": "Card Holder Name",
  "Select an option to Pay ": "Select an option to Pay ",
  "Merchant has no permission to use SDK. Please contact to administrator.": "Merchant has no permission to use SDK. Please contact to administrator.",


  "100% secured Payment ": "100% secured Payment ",
  "Powered by Sadad": "Powered by Sadad",
  "Login with your Sadad account": "Login with your Sadad account",
  "CVV is the three digit number on the back of your credit/debit card.": "CVV is the three digit number on the back of your credit/debit card.",
  "What is CVV": "What is CVV",
  "Please enter card holder name": "Please enter card holder name",
  "Card holder name is invalid.": "Card holder name is invalid.",
  "Please enter card number": "Please enter card number",
  "Please enter a valid credit card number.": "Please enter a valid credit card number.",
  "We are not accepting this card": "We are not accepting this card",
  "This is not a valid credit card number": "This is not a valid credit card number",
  "Please enter expiry.": "Please enter expiry.",
  "Enter valid expiry.": "Enter valid expiry.",
  "Please enter CVV": "Please enter CVV",
  "Please enter valid expiry.": "Please enter valid expiry.",
  "Please enter valid CVV": "Please enter valid CVV",
  "Not Allowed": "Not Allowed",
  "Transaction is not allowed from your country.": "Transaction is not allowed from your country.",
  "Please enter cell number.": "Please enter cell number.",
  "Please enter valid cell number": "Please enter valid cell number",
  "Please enter password": "Please enter password",
  "Issue": "Issue",
  "We are not able to process your payment.": "We are not able to process your payment.",
  "Something went wrong": "Something went wrong",
  "OTP Verification": "OTP Verification",
  "OTP is valid Upto ": "OTP is valid Upto ",
  "Can't receive the OTP? ": "Can't receive the OTP? ",
  "Resend": "Resend",
  "seconds": "seconds",
};
